You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2015/12/29 01:51:12 UTC

[math] Minor change.

Repository: commons-math
Updated Branches:
  refs/heads/master 8bcf7e23a -> d1123894d


Minor change.

Make method parameter names consistent (cf. MATH-1307).


Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/d1123894
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/d1123894
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/d1123894

Branch: refs/heads/master
Commit: d1123894d33922e7c8ca838f9dac9bdceefa3f7a
Parents: 8bcf7e2
Author: Gilles <er...@apache.org>
Authored: Tue Dec 29 01:49:36 2015 +0100
Committer: Gilles <er...@apache.org>
Committed: Tue Dec 29 01:49:36 2015 +0100

----------------------------------------------------------------------
 .../commons/math4/random/BaseRandomGenerator.java     | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/d1123894/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java b/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
index da801b0..bc6442e 100644
--- a/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/BaseRandomGenerator.java
@@ -228,17 +228,17 @@ public abstract class BaseRandomGenerator
      * </p>
      *
      * @param bytes Array in which to put the generated bytes. Cannot be {@code null}.
      * @param position Index at which to start inserting the generated bytes.
      * @param length Number of bytes to insert.
      */
     private void nextBytesFill(byte[] bytes,
-                               int position,
-                               int length) {
-        int index = position; // Index of first insertion.
+                               int start,
+                               int len) {
+        int index = start; // Index of first insertion.
 
         // Index of first insertion plus multiple 4 part of length (i.e. length
         // with two least significant bits unset).
-        final int indexLoopLimit = index + (length & 0x7ffffffc);
+        final int indexLoopLimit = index + (len & 0x7ffffffc);
 
         // Start filling in the byte array, 4 bytes at a time.
         while (index < indexLoopLimit) {
@@ -249,7 +249,7 @@ public abstract class BaseRandomGenerator
             bytes[index++] = (byte) (random >>> 24);
         }
 
-        final int indexLimit = position + length; // Index of last insertion + 1.
+        final int indexLimit = start + len; // Index of last insertion + 1.
 
         // Fill in the remaining bytes.
         if (index < indexLimit) {
@@ -228,17 +228,17 @@ public abstract class BaseRandomGenerator
      *
      * @param bytes Array in which to put the generated bytes. Cannot be {@code null}.
-     * @param position Index at which to start inserting the generated bytes.
-     * @param length Number of bytes to insert.
+     * @param start Index at which to start inserting the generated bytes.
+     * @param len Number of bytes to insert.
      */
     private void nextBytesFill(byte[] bytes,